LibriTTS is a multi-speaker English corpus of approximately 585 hours of read
English speech at 24kHz sampling rate, prepared by Heiga Zen with the assistance
of Google Speech and Google Brain team members. The LibriTTS corpus is designed
for TTS research. It is derived from the original materials (mp3 audio files
from LibriVox and text files from Project Gutenberg) of the LibriSpeech corpus.
The main differences from the LibriSpeech corpus are listed below:

1.  The audio files are at 24kHz sampling rate.
2.  The speech is split at sentence breaks.
3.  Both original and normalized texts are included.
4.  Contextual information (e.g., neighbouring sentences) can be extracted.
5.  Utterances with significant background noise are excluded.
